@@ -3,8 +3,12 @@
  *
  * pdfresurrect - PDF history extraction tool
  *
- * Copyright (C) 2008, 2009, 2010, 2012 Matt Davis (enferex) of 757Labs
- * (www.757labs.org)
+ * Copyright (C) 2008, 2009, 2010, 2012, 2017 Matt Davis (enferex).
+ *
+ * Special thanks to all of the contributors:  See AUTHORS.
+ *
+ * Special thanks to 757labs (757 crew), they are a great group
+ * of people to hack on projects and brainstorm with.
  *
  * main.c is part of pdfresurrect.
  * pdfresurrect is free software: you can redistribute it and/or modify
@@ -33,9 +37,9 @@
 
 static void usage(void)
 {
-    printf(EXEC_NAME " Copyright (C) 2008, 2009, 2010, 2012 "
+    printf(EXEC_NAME " Copyright (C) 2008, 2009, 2010, 2012, 2013, 2017 "
            "Matt Davis (enferex)\n"
-           "of 757labs (www.757labs.org)\n"
+           "Special thanks to all contributors and the 757 crew.\n"
            "This program comes with ABSOLUTELY NO WARRANTY\n"
            "This is free software, and you are welcome to redistribute it\n"
            "under certain conditions.  For details see the file 'LICENSE'\n"
@@ -59,8 +63,8 @@ static void write_version(
     const char *dirname,
     xref_t     *xref)
 {
-    long  start, end, startxref, pos, pos_count;
-    char *c, *xref_buf, *new_fname, data, peek;
+    long  start;
+    char *c, *new_fname, data;
     FILE *new_fp;
     
     start = ftell(fp);
@@ -84,44 +88,13 @@ static void write_version(
     fseek(fp, 0, SEEK_SET);
     while (fread(&data, 1, 1, fp))
       fwrite(&data, 1, 1, new_fp);
-    fprintf(new_fp, "\r\n");
 
-    /* Go backwards till we hit the end of 'startxref' */
-    fseek(fp, xref->end, SEEK_SET);
-    pos = xref->end;
-    pos_count = 0;
-    while ((peek = fgetc(fp) != 'f'))
-      fseek(fp, pos - (++pos_count), SEEK_SET);
-    end = ftell(fp);
-
-    /* Suck in xref to copy */
-    fseek(fp, xref->start, SEEK_SET);
-    xref_buf = malloc(end - xref->start);
-    if (!(fread(xref_buf, end - xref->start, 1, fp)))
-    {
-        ERR("Could not read %d bytes from document\n",
-             (int)(xref->end - xref->start));
-
-        fclose(new_fp);
-        free(new_fname);
-        fseek(fp, start, SEEK_SET);
-        return;
-    }
-
-    /* Append that copy (ending at 'startxref') */
-    startxref = ftell(new_fp);
-    if (!(fwrite(xref_buf, end - xref->start, 1, new_fp)))
-    {
-        ERR("Could not write %d bytes to document\n",
-            (int)(end - xref->start));
-    }
-
-    fprintf(new_fp, "\r\n%ld\r\n%%%%EOF", startxref);
+    /* Emit an older startxref, refering to an older version. */
+    fprintf(new_fp, "\r\nstartxref\r\n%ld\r\n%%%%EOF", xref->start);
 
     /* Clean */
     fclose(new_fp);
     free(new_fname);
-    free(xref_buf);
     fseek(fp, start, SEEK_SET);
 }
 
