@@ -3,8 +3,12 @@
  *
  * pdfresurrect - PDF history extraction tool
  *
- * Copyright (C) 2008, 2009, 2010, 2012 Matt Davis (enferex) of 757Labs
- * (www.757labs.org)
+ * Copyright (C) 2008-2010, 2012-2013, 2017, Matt Davis (enferex).
+ *
+ * Special thanks to all of the contributors:  See AUTHORS.
+ *
+ * Special thanks to 757labs (757 crew), they are a great group
+ * of people to hack on projects and brainstorm with.
  *
  * pdf.c is part of pdfresurrect.
  * pdfresurrect is free software: you can redistribute it and/or modify
@@ -730,6 +734,9 @@ static void resolve_linearized_pdf(pdf_t *pdf)
     int    i;
     xref_t buf;
 
+    if (pdf->n_xrefs < 2)
+      return;
+
     if (!pdf->xrefs[0].is_linear)
       return;
 
@@ -925,7 +932,7 @@ static void load_creator_from_old_format(
              ++c;
 
             /* Advance the search to the next token */
-            while (s && ((*s != '\r') || (*s != '\n')) && (*s == '/'))
+            while (s && (*s == '/'))
               ++s;
             saved_buf_search = s;
         }
